@@ -129,7 +129,7 @@ if (isset($save_x)) {
     // RECREATE USER GROUPS
     begin_transaction();
     $gdel = new dbdelete("ax_user_group");
-    $gdel->where("user_id='" . addslashes($userid) . "'");
+    $gdel->where("user_id='" . escape_string($userid) . "'");
     $gdel->execute();
     $allgQ = dbrecordset("SELECT * FROM ax_group");
     if ($allgQ->hasdata) {
@@ -149,7 +149,7 @@ if (isset($save_x)) {
     // RECREATE IP ADDRESSES
     begin_transaction();
     $ipdel = new dbdelete("ax_user_ip");
-    $ipdel->where("user_id='" . addslashes($userid) . "'");
+    $ipdel->where("user_id='" . escape_string($userid) . "'");
     $ipdel->execute();
     if (isset($iplist) && trim($iplist) != "") {
       $iplist = str_replace(",", "", $iplist);
@@ -158,7 +158,7 @@ if (isset($save_x)) {
         // Avoid duplicates..
         $ip = ip_format($ip);
         $q  = "SELECT * FROM ax_user_ip";
-        $q .= " WHERE user_id='" . addslashes($userid) . "'";
+        $q .= " WHERE user_id='" . escape_string($userid) . "'";
         switch ($RESPONSE->datasource->dbtype()) {
           case "postgres":
             $q .= " AND ip= inet '$ip'";
@@ -184,23 +184,23 @@ elseif ($mode == "remove") {
     // Delete all related records, then, finally, ax_user..
     start_transaction();
     $udel = new dbdelete("ax_wwwsession");
-    $udel->where("user_id='" . addslashes($userid) . "'");
+    $udel->where("user_id='" . escape_string($userid) . "'");
     $udel->execute();
 
     $udel = new dbdelete("ax_user_ip");
-    $udel->where("user_id='" . addslashes($userid) . "'");
+    $udel->where("user_id='" . escape_string($userid) . "'");
     $udel->execute();
 
     $udel = new dbdelete("ax_forum_member");
-    $udel->where("user_id='" . addslashes($userid) . "'");
+    $udel->where("user_id='" . escape_string($userid) . "'");
     $udel->execute();
 
     $udel = new dbdelete("ax_user_group");
-    $udel->where("user_id='" . addslashes($userid) . "'");
+    $udel->where("user_id='" . escape_string($userid) . "'");
     $udel->execute();
 
     $udel = new dbdelete("ax_user");
-    $udel->where("user_id='" . addslashes($userid) . "'");
+    $udel->where("user_id='" . escape_string($userid) . "'");
     $udel->execute();
     commit();
   }
@@ -495,7 +495,7 @@ if ($recvalid) {
   $s  = "<table border=0 cellpadding=2 cellspacing=0 width=100%>";
   $s .= "<tr><td>";
 
-  $ipQ = dbrecordset("SELECT * FROM ax_user_ip WHERE user_id='" . addslashes($userid) . "'");
+  $ipQ = dbrecordset("SELECT * FROM ax_user_ip WHERE user_id='" . escape_string($userid) . "'");
   $ips = array();
   if ($ipQ->hasdata) {
     do {
