@@ -104,6 +104,9 @@ if (open APPXML, "<$appxml" ) {
         elsif (/.*?parameter name=\"microsites_enabled\".*?/) {
           $line = "      \<parameter name=\"microsites_enabled\" type=\"boolean\"\>$MICRO\<\/parameter\>\n";
         }
+        elsif (/.*?parameter name=\"cookiename\".*?/) {
+          $line = "      \<parameter name=\"cookiename\" type=\"string\"\>" . $APP_PREFIX . "_session_id\<\/parameter\>\n";
+        }
       }
       print APPXMLTMP $line;
     }
