@@ -78,23 +78,22 @@ fi
 # Set up the required users and groups
 
 # The Axyl user..
-mkuser $AXUSER $AXUSER $AXYL_HOME /bin/false Axyl Admin
+mkuser $AXUSER system default any default default "Axyl Administrator"
 
 # Webserver user and group..
 WWWUSER=www-data
 WWWGROUP=www-data
-if [ -r ${APACHE_CONFDIR}/httpd.conf ]
-then
+WWWADMIN=wwwadmin
+if [ -r ${APACHE_CONFDIR}/httpd.conf ] ; then
   G=`grep "^Group " ${APACHE_CONFDIR}/httpd.conf | cut -d" " -f2`
   U=`grep "^User " ${APACHE_CONFDIR}/httpd.conf | cut -d" " -f2`
   [ "$G" != "" ] && WWWGROUP=$G
   [ "$U" != "" ] && WWWUSER=$U
 fi
-mkuser $WWWUSER $WWWGROUP /var/www /bin/sh WWW User
+mkuser $WWWUSER system $WWWGROUP any /var/www default "WWW User"
 
 # Web hosting administration group..
-WWWADMIN=wwwadmin
-mkgroup $WWWADMIN
+mkgroup $WWWADMIN any
 
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 # AXYL INSTALLATION LOCATION
@@ -172,7 +171,7 @@ else
 fi
 
 # Create directory and set perms..
-mkaxyldir $AXYL_DATA
+mkthisdir $AXYL_DATA
 chown -R ${AXUSER}:${AXUSER} ${AXYL_DATA}
 chmod -R 0644 ${AXYL_DATA}
 find ${AXYL_DATA} -type d -exec chmod 6755 {} \;
@@ -187,7 +186,7 @@ else
 fi
 
 # Create directory and set perms..
-mkaxyldir $AXYL_LOGS
+mkthisdir $AXYL_LOGS
 chown -R ${AXUSER}:${AXUSER} ${AXYL_LOGS}
 find ${AXYL_LOGS} -type f -exec chmod 6755 {} \;
 find ${AXYL_LOGS} -type d -exec chmod 6755 {} \;
@@ -318,11 +317,14 @@ read ANS
 [ "$ANS" != "" ] && WWW_PATH=$ANS
 
 # Create the full destination path..
-mkaxyldir $WWW_PATH
+mkthisdir $WWW_PATH
+
+# Copy across initial content..
+dupedir ${AXYL_HOME}/www ${WWW_PATH}
 
 # Axyl library images and javascript. These need
 # to be actually in the website hiearchy..
-mkaxyldir ${WWW_PATH}/lib
+mkthisdir ${WWW_PATH}/lib
 if [ ! -L ${WWW_PATH}/lib/img ]
 then
   ln -s ${AXYL_HOME}/lib/img ${WWW_PATH}/lib/img
@@ -332,9 +334,6 @@ then
   ln -s ${AXYL_HOME}/lib/js ${WWW_PATH}/lib/js
 fi
 
-# Copy across initial content..
-dupedir ${AXYL_HOME}/www ${WWW_PATH}
-
 # If non-Postgres installation, then we have to replace some of the
 # maintenance scripts with ones which are compatible with other
 # databases. The standard scripts use the Axyl maintainer-defs.php
@@ -384,40 +383,44 @@ then
   CONF=${APACHE_CONFDIR}/httpd.conf
   TMP=/tmp/$$
 
-  # Virtual host
-  VHOST=localhost
-  A=`perl -n -e "m;^[\s]*NameVirtualHost;i && s;\*;ASTERISK; && print;" $CONF`
-  if [ "$A" != "" ]
-  then
-    for bit in $A
-    do
-      VHOST=$bit
-    done
+  echo ""
+  echo "Ok, you now have to specify the IP address, or hostname of the"
+  echo "server that will be serving your website. Apache allows this to"
+  echo "be 'loose', as in '*:80' which indicates any IP address, on"
+  echo "port 80 (the default below)."
+  echo ""
+  
+  # Display current NameVirtualHost settings if any..
+  A=`perl -n -e "m;^[\s]*NameVirtualHost;i && s;NameVirtualHost ;;i && print;" $CONF`
+  if [ "$A" != "" ] ; then
+    echo "Your installation has some NameVirtualHost settings, apparently, and"
+    echo "these are listed here for a source of answers to the below."
+    echo "Your current NameVirtualHosts: $A"
+    echo ""
   fi
-  DISP=$VHOST
-  [ "$DISP" = "ASTERISK" ] && DISP="*"
+  
+  DISP="Everything on Port 80"
+  VHOST="*:80"
+  set -f
   echo -n "Enter IP or hostname for this virtual host [${DISP}] :"
   read ANS
   [ "$ANS" != "" ] && VHOST=$ANS
+  set +f
 
   # Server name
   SERVERNAME=
   VSERVERNAME=
   A=`perl -n -e "m;^[\s]*ServerName;i && print;" $CONF`
-  if [ "$A" != "" ]
-  then
-    for bit in $A
-    do
+  if [ "$A" != "" ] ; then
+    for bit in $A ; do
       SERVERNAME=$bit
     done
     host="`echo $SERVERNAME | cut -d'.' -f1`"
-    if [ "$host" != "" ]
-    then
+    if [ "$host" != "" ] ; then
       VSERVERNAME="`echo $SERVERNAME | sed -e \"s/${host}/${DBNAME}/\"`"
     fi
   fi
-  if [ "$VSERVERNAME" = "" ]
-  then
+  if [ "$VSERVERNAME" = "" ] ; then
     VSERVERNAME=$DBNAME
   fi
   echo -n "Enter the ServerName [${VSERVERNAME}] :"
@@ -509,15 +512,17 @@ echo ""
 echo "setting up website application config file (application.xml).."
 ${AXYL_HOME}/install/config-app-db.pl $INST_NAME $WWW_PATH $DBTYPE $DBNAME $DBUSER $DBPASSWD $DBHOST $DBPORT $META $MICRO
 # Fix up perms..
-chown ${AXUSER}:${WWWADMIN} ${WWW_PATH}/application.xml*
-chmod 0664 ${WWW_PATH}/application.xml*
+chown ${AXUSER}:${WWWADMIN} ${WWW_PATH}/application.xml
+chmod 0664 ${WWW_PATH}/application.xml
 
 # Customise Apache if required..
 echo ""
 if [ "$CONFIG_APACHE" = "yes" ]
 then
   echo "Configuring Apache"
+  set -f
   ${AXYL_HOME}/install/config-apache.sh $VHOST $VSERVERNAME $ADMIN_EMAIL $DOCROOT $MAXMEM $MAXUPLOAD
+  set +f
 fi
 
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -564,23 +569,22 @@ if [ "$CONFIG_APACHE" = "yes" ]
 then
   echo "Apache was configured with server name '${VSERVERNAME}'"
   echo "however you will now have to set up your DNS or /etc/hosts file"
-  echo "appropriately to resolve this for visiting web clients. As part"
-  echo "of this apache configuration, Php has been configured and some"
-  echo "settings may have been changed in the php.ini files."
+  echo "appropriately to resolve this for visiting web clients."
 fi
 echo ""
 echo "The Axyl configuration is in your 'application.xml' in the website"
 echo "root directory '${WWW_PATH}'. To maintain this the"
 echo "recommended approach is to change it using the GUI maint script"
-echo "lib/control-panel.php GUI, by soft-linking it up into the website"
-echo "root and pointing your browser at it and having it writeable to"
-echo "the webserver, so you can make the necessary changes."
+echo "lib/control-panel.php, by soft-linking it up into the website root"
+echo "and then pointing your browser at it. If you do this, then make sure"
+echo "'application.xml' is writeable to the webserver, so you can make the"
+echo "necessary changes."
 echo ""
-echo "However, this should be done on a developer copy of the website,"
-echo "and not on the Live version. Once you have it as required, you"
-echo "can then copy it over the top of your production copy, which is"
-echo "kept as non-writeable to the web-server."
+echo "However, this should be only ever be done on a developer copy of the"
+echo "website, and not on the Live version. Once you have it as required,"
+echo "you can then copy it over the top of your production copy, which is"
+echo "always kept as non-writeable to the web-server."
 echo ""
 echo "The Axyl Team"
 
-# END
\ No newline at end of file
+# END
