@@ -27,7 +27,7 @@ fi
 # ASSERT MAIN INSTALLATION PERMISSIONS and OWNERSHIP
 if [ "${AXYL_HOME}" != "" ]
 then
-  chown -R ${AXUSER}.${AXUSER} ${AXYL_HOME}
+  chown -R ${AXUSER}:${AXUSER} ${AXYL_HOME}
   chmod -R 0664 ${AXYL_HOME}
   chmod -R g+sw ${AXYL_HOME}
   find ${AXYL_HOME} -type d -exec chmod a+x {} \;
