@@ -25,8 +25,10 @@
 /* ******************************************************************** */
 /** @package catalog */
 
-/** Lucene indexing/searching */
-include_once("lucene-defs.php");
+/** indexing/searching */
+include_once("search-lucene-defs.php");
+include_once("search-index-defs.php");
+include_once("search-query-defs.php");
 /** Filesystem access */
 include_once("file-defs.php");
 
@@ -142,7 +144,7 @@ class catalogitem extends RenderableObject {
       $cup->set("upload_timestamp", timestamp_to_datetime($this->uploaded_ts));
       $res = $cup->execute();
       if ($res) {
-        // Index to Lucene..
+        // Index to search engine..
         $this->index();
         // Update status of physical file..
         $this->physicalpath = $RESPONSE->site_docroot . $this->filepath;
@@ -182,7 +184,7 @@ class catalogitem extends RenderableObject {
         $dcat->where("cat_id=$this->cat_id");
         $res = $dcat->execute();
         if ($res) {
-          // Remove from Lucene index..
+          // Remove from search engine index..
           $this->unindex();
           $this->valid = false;
           $deleted = true;
@@ -193,13 +195,13 @@ class catalogitem extends RenderableObject {
   }  // delete
   // .....................................................................
   /**
-  * Index this catalog item to Lucene.
+  * Index this catalog item to the search engine.
   * If it exists already, index entry for this item is replaced.
   */
   function index() {
-    global $CONTEXT;
-    if ($this->valid && isset($CONTEXT) && $CONTEXT->configvalue("Lucene Site Indexing") ) {
-      $I = new lucene_indexmsg();
+    global $SE_AVAILABLE;
+    if ($this->valid && $SE_AVAILABLE) {
+      $I = new searchengine_indexer();
       // Make sure these fields are stored..
       $I->define_field("catname", "Text", STORED);
       $I->define_field("category", "Text", STORED);
@@ -219,17 +221,17 @@ class catalogitem extends RenderableObject {
       $allcontent[] = $this->cat_desc;
       $allcontent[] = $this->keywords;
       $I->index_content("CAT_" . $this->cat_id, implode(" ", $allcontent));
-      $I->send();
+      $I->execute();
     }
   } // index
   // .....................................................................
-  /** Remove this catalog item from the Lucene index. */
+  /** Remove this catalog item from the search engine index. */
   function unindex() {
-    global $CONTEXT;
-    if ($this->valid && isset($CONTEXT) && $CONTEXT->configvalue("Lucene Site Indexing") ) {
-      $UI = new lucene_unindexmsg();
+    global $SE_AVAILABLE;
+    if ($this->valid && $SE_AVAILABLE) {
+      $UI = new searchengine_unindexer();
       $UI->unindex("CAT_" . $this->cat_id);
-      $UI->send();
+      $UI->execute();
     }
   } // unindex
   // .....................................................................
@@ -431,14 +433,12 @@ class catalogitem extends RenderableObject {
       // Check pre-existence/overwrite flag..
       if (!file_exists($destpath) || isset($_overwrite)) {
         // Determine mime_category..
-        if ($mime_category == "" ) {
+        $mime_category = mimetype_category($file_mime);
+        if ($mime_category == "") {
+          $file_mime = mimetype_from_filename($up->filename);
           $mime_category = mimetype_category($file_mime);
           if ($mime_category == "") {
-            $file_mime = mimetype_from_filename($up->filename);
-            $mime_category = mimetype_category($file_mime);
-            if ($mime_category == "") {
-              $errmsgs[] = "That file is of a type unknown to the system [$file_mime].";
-            }
+            $errmsgs[] = "That file is of a type unknown to the system [$file_mime].";
           }
         }
         // Carry on if legal mime_category..
@@ -579,8 +579,8 @@ class catalog extends RenderableObject {
   } // get_catalogitem_by_filepath
   // .....................................................................
   /**
-  * Perform a search for catalog items. This method will use Lucene
-  * if it is available and keywords are provided, otherwise it will
+  * Perform a search for catalog items. This method will use the search
+  * engine if it is available and keywords are provided, otherwise it will
   * just go to the database. The end result is that this catalog is
   * populated with the results of the search, having been cleared out
   * beforehand.
@@ -590,14 +590,14 @@ class catalog extends RenderableObject {
   * @param strong $sortby Sort order for results
   */
   function search($keywords="", $mimecats="", $categories="", $sortby="") {
-    global $CONTEXT;
+    global $SE_AVAILABLE;
 
     // Initialise catalog..
     $this->catalogitems = array();
 
-    // LUCENE KEYWORD SEARCH..
-    if ($keywords != "" && isset($CONTEXT) && $CONTEXT->configvalue("Lucene Site Indexing")) {
-      $thesearch = new lucene_search();
+    // KEYWORD SEARCH..
+    if ($keywords != "" && $SE_AVAILABLE) {
+      $thesearch = new searchengine_search();
 
       // CONTENT TYPES
       if (is_array($mimecats) && count($mimecats) > 0) {
@@ -688,7 +688,7 @@ class catalog extends RenderableObject {
         }
       }
 
-    } // got keywords & lucene
+    } // got keywords
     else {
       $cQ  = new dbselect("ax_catalog");
       $wheres = array();
@@ -705,7 +705,6 @@ class catalog extends RenderableObject {
       if (is_array($categories) && count($categories) > 0) {
         // The nullstring represents 'Any' or 'All'..
         if (!in_array("", $categories)) {
-          if ($where != "") $where .= " AND ";
           $wheres[] = "category IN ('" . implode("','", $categories) . "')";
         }
       }
@@ -758,7 +757,7 @@ class catalog extends RenderableObject {
   */
   function html() {
     global $RESPONSE, $LIBDIR;
-    return $s;
+    return "";
   } // html
 
 } // catalog class
