@@ -40,8 +40,8 @@ class db_oracle extends database {
   var $numrows = 0;
   // ....................................................................
   /** Constructor */
-  function db_oracle($name="", $user="", $passwd="", $host="", $port=1521) {
-    $this->database($name, $user, $passwd, $host, $port);
+  function db_oracle($name="", $user="", $passwd="", $host="", $port=1521, $enc="", $datestyle="") {
+    $this->database($name, $user, $passwd, $host, $port, $enc, $datestyle);
     $this->type = "oracle";
   }
   // ....................................................................
