@@ -48,10 +48,12 @@ define("DBG_TRACE",      32);
 define("DBG_TABLES",     64);
 /** Show debugging profiler output */
 define("DBG_PROFILE",   128);
+/** Show site authentication output */
+define("DBG_AUTH",      256);
 /** DEBUG and DIAGNOSTICS as default setting */
 define("DBG_DEFAULT",     3);
 /** Everything. Warning, this can be VERBOSE! */
-define("DBG_ALL",       255);
+define("DBG_ALL",       511);
 
 // Defined output options. Where debug output goes..
 /** No output */
@@ -89,6 +91,8 @@ define("DBG_O_ALL",     255);
 *    DBG_DUMP           Dump HTTP and PHP page vars
 *    DBG_TRACE          Provide debug traceback info
 *    DBG_TABLES         Show table borders and validate cells
+*    DBG_PROFILES       Show process profiling information
+*    DBG_AUTH           Authentication messages
 *    DBG_DEFAULT        DEBUG and DIAGNOSTICS only
 *    DBG_ALL            Everything (verbose!)
 * eg. debug_on(DBG_SQL | DBG_DIAGNOSTIC | DBG_DUMP);
@@ -99,7 +103,7 @@ class webdebugger extends RenderableObject {
   /** Accumulated debugging output content */
   var $content = "";
   /** Classes of debugging to accumulate */
-  var $class = DBG_DEFAULT;
+  var $debugclass = DBG_DEFAULT;
   /** Status of the debugger */
   var $enabled = false;
   /** Modes of output for debugging content */
@@ -122,10 +126,10 @@ class webdebugger extends RenderableObject {
   // ................................................................
   /**
   * Constructor
-  * @param integer $class The classes of output to render
+  * @param integer $debugclass The classes of output to render
   */
-  function webdebugger($class=DBG_DEFAULT) {
-    $this->debug_class($class);
+  function webdebugger($debugclass=DBG_DEFAULT) {
+    $this->debug_class($debugclass);
   }
   // ................................................................
   /**
@@ -136,7 +140,7 @@ class webdebugger extends RenderableObject {
       $this->enabled &&
       (
         (strlen($this->content) > 0)
-        || ($this->class & DBG_DUMP)
+        || ($this->debugclass & DBG_DUMP)
         || ($this->profiling() && count($this->profile) > 0)
       )
     );
@@ -151,7 +155,7 @@ class webdebugger extends RenderableObject {
   *    DBG_O_NONE       No output
   *    DBG_O_STORED     Output stored in $content
   *    DBG_O_ECHO       Output via direct echo
-  *    DBG_O_CLI        Output for CLI: echoed raw ASCII, LF end-of-line
+  *    DBG_O_CLI        Output for CLI: echoed tag-stripped ASCII, LF end-of-line
   *    DBG_O_LOG        Output to system log
   *    DBG_O_LOGFILE    To logfile (not implemented yet)
   *    DBG_O_DEFAULT    Default output mode (echoed)
@@ -166,19 +170,19 @@ class webdebugger extends RenderableObject {
   * Set debug output mode
   * Register content for debugging output. Check that it is
   * of an acceptable class and direct it all to the right place(s).
-  * @param string  $content  Content to add to debug output buffer
-  * @param integer $class    Class of output
+  * @param string  $content Content to add to debug output buffer
+  * @param integer $debugclass Class of output
   */
-  function debug_write($content, $class=DBG_DIAGNOSTIC) {
+  function debug_write($content, $debugclass=DBG_DIAGNOSTIC) {
     if ($this->enabled) {
       // Are we providing traceback info..
-      if ($this->class & DBG_TRACE) {
+      if ($this->debugclass & DBG_TRACE) {
         if ($this->tracedepth > 0) {
           $content .= "[ " . $this->traceback() . " ] ";
         }
       }
       // Direct debugging content where we should..
-      if ($class & $this->class) {
+      if ($debugclass & $this->debugclass) {
         if ($this->output_mode & DBG_O_STORED) {
           $this->content .= $content;
         }
@@ -186,11 +190,14 @@ class webdebugger extends RenderableObject {
           echo $content;
         }
         if ($this->output_mode & DBG_O_CLI) {
-          $s = str_replace("<br>", "\n", $content);
+          $s = str_replace("<br>", "\n", html_entity_decode($content));
+          if (!strstr($content, "<pre>")) {
+            $s =  strip_tags($s);
+          }
           echo $s;
         }
         if ($this->output_mode & DBG_O_LOG) {
-          error_log(strip_tags($content), 0);
+          error_log(strip_tags(html_entity_decode($content)), 0);
         }
       }
     }
@@ -199,12 +206,12 @@ class webdebugger extends RenderableObject {
   // ................................................................
   /**
   * Set debug class(es) to accept
-  * @param integer $class Class of output
+  * @param integer $debugclass Class of output
   */
-  function debug_class($class) {
-    if (isset($class)) {
-      $this->class = $class & DBG_ALL;
-      if ($this->class == DBG_NONE)
+  function debug_class($debugclass) {
+    if (isset($debugclass)) {
+      $this->debugclass = $debugclass & DBG_ALL;
+      if ($this->debugclass == DBG_NONE)
         $this->enabled = false;
     }
     return $this;
@@ -214,12 +221,12 @@ class webdebugger extends RenderableObject {
   * Set debug mode
   * Set debug output to be enabled(default)/disabled
   * @param boolean  $enabled  If true enable debugger, else disable it
-  * @param integer $class     Class of output to accept
+  * @param integer $debugclass     Class of output to accept
   */
-  function debug_mode($enabled=true, $class=DBG_UNDEFINED) {
+  function debug_mode($enabled=true, $debugclass=DBG_UNDEFINED) {
     $this->enabled = $enabled;
     if ($enabled) {
-      $this->debug_class($class);
+      $this->debug_class($debugclass);
     }
     return $this;
   }
@@ -230,7 +237,7 @@ class webdebugger extends RenderableObject {
   * @access private
   */
   function debug_dump() {
-    $this->class |= DBG_DUMP;
+    $this->debugclass |= DBG_DUMP;
     return $this;
   }
   // ................................................................
@@ -291,7 +298,7 @@ class webdebugger extends RenderableObject {
   // ................................................................
   /** Returns true if this debugger is in profiling mode. */
   function profiling() {
-    return $this->class & DBG_PROFILE;
+    return $this->debugclass & DBG_PROFILE;
   }
   // ................................................................
   /**
@@ -299,17 +306,16 @@ class webdebugger extends RenderableObject {
   * @return string List of classes acceptable to the debugger
   */
   function report_classes() {
-    $s = "";
-    if ($this->class & DBG_TRACE)      $s .= "TRACEBACK ";
-    if ($this->class & DBG_SQL)        $s .= "SQL ";
-    if ($this->class & DBG_DEBUG)      $s .= "DEBUG ";
-    if ($this->class & DBG_DIAGNOSTIC) $s .= "DIAGNOSTIC ";
-    if ($this->class & DBG_DUMP)       $s .= "DUMP ";
-    if ($this->class & DBG_TABLES)     $s .= "TABLES ";
-    if ($this->class & DBG_PROFILE)    $s .= "PROFILER ";
-    $s = trim($s);
-    $s = str_replace(" ", ",", $s);
-    return $s;
+    $rpt = array();
+    if ($this->debugclass & DBG_TRACE)      $rpt[] = "TRACEBACK";
+    if ($this->debugclass & DBG_SQL)        $rpt[] = "SQL";
+    if ($this->debugclass & DBG_DEBUG)      $rpt[] = "DEBUG";
+    if ($this->debugclass & DBG_DIAGNOSTIC) $rpt[] = "DIAGNOSTIC";
+    if ($this->debugclass & DBG_DUMP)       $rpt[] = "DUMP";
+    if ($this->debugclass & DBG_TABLES)     $rpt[] = "TABLES";
+    if ($this->debugclass & DBG_PROFILE)    $rpt[] = "PROFILER";
+    if ($this->debugclass & DBG_AUTH)       $rpt[] = "AUTH";
+    return implode(",", $rpt);
   }
   // ................................................................
   /**
@@ -321,7 +327,7 @@ class webdebugger extends RenderableObject {
   * @access private
   */
   function pushtrace($traceobj) {
-    if ($this->class & DBG_TRACE) {
+    if ($this->debugclass & DBG_TRACE) {
       // First determine the trace label..
       if (is_object($traceobj)) {
         $label = "<font color=blue>" . get_class($traceobj) . "</font>";
@@ -348,7 +354,7 @@ class webdebugger extends RenderableObject {
   * @access private
   */
   function poptrace() {
-    if ($this->class & DBG_TRACE) {
+    if ($this->debugclass & DBG_TRACE) {
       if ($this->tracedepth > 0) {
         $label = array_pop($this->trace);
         if ($this->profiling()) {
@@ -420,7 +426,7 @@ class webdebugger extends RenderableObject {
     $header .= "<b>Debug filter: " . $this->report_classes() . "</b><br>";
     $header .= "</p>";
     $footer = "+++ END OF DEBUG OUTPUT +++<br>";
-    if ($this->class & DBG_DUMP) {
+    if ($this->debugclass & DBG_DUMP) {
       $s  ="<p>";
       $s .= "<table border=1 cellpadding=2 cellspacing=0>";
       if (isset($$vname_cookie)) {
@@ -540,7 +546,7 @@ class webdebugger extends RenderableObject {
     global $$vname_post;
     global $GLOBALS;
     $s = "";
-    if ($this->class & DBG_DUMP) {
+    if ($this->debugclass & DBG_DUMP) {
       $s .= "<b>Variables</b><br/>";
       if (isset($$vname_get)) {
         $s .= "GET Vars:<br/>";
@@ -600,12 +606,12 @@ class webdebugger extends RenderableObject {
 * The output will then appear as per the output settings.
 * @see debugbr()
 * @param string  $content  Content to add to debug output buffer
-* @param integer $class    Class of output
+* @param integer $debugclass    Class of output
 */
-function debug($content, $class=DBG_DIAGNOSTIC) {
+function debug($content, $debugclass=DBG_DIAGNOSTIC) {
   global $RESPONSE;
   if (isset($RESPONSE)) {
-    $RESPONSE->debugger->debug_write($content, $class);
+    $RESPONSE->debugger->debug_write($content, $debugclass);
   }
 }
 // ..................................................................
@@ -615,10 +621,10 @@ function debug($content, $class=DBG_DIAGNOSTIC) {
 * <br> to it. This is intended for output to HTML pages.
 * @see debug()
 * @param string  $content  Content to add to debug output buffer
-* @param integer $class    Class of output
+* @param integer $debugclass    Class of output
 */
-function debugbr($content, $class=DBG_DIAGNOSTIC) {
-  debug($content . "<br>", $class);
+function debugbr($content, $debugclass=DBG_DIAGNOSTIC) {
+  debug($content . "<br>", $debugclass);
 }
 // ..................................................................
 /**
@@ -633,24 +639,24 @@ function debugbr($content, $class=DBG_DIAGNOSTIC) {
 *     ASCII values > 127 ................. Green
 * @param string  $str    String to view as hex
 * @param string  $msg    Message to title the dump with
-* @param integer $class    Class of output
+* @param integer $debugclass    Class of output
 */
-function debug_hex($str, $msg="", $class=DBG_DIAGNOSTIC) {
+function debug_hex($str, $msg="", $debugclass=DBG_DIAGNOSTIC) {
   if (is_string($str)) {
     if ($msg != "") {
-      debugbr($msg, $class);
+      debugbr($msg, $debugclass);
     }
-    debug("<pre>", $class);
+    debug("<pre>", $debugclass);
     for ($i=0; $i < strlen($str); $i++) {
       $c = ord(substr($str, $i, 1));
       $xc = sprintf("%02x", $c);
       if ($c == 32)      $xc = "<font color=blue>$xc</font>";
       elseif ($c < 32)  $xc = "<font color=red>$xc</font>";
       elseif ($c > 127) $xc = "<font color=green>$xc</font>";
-      debug("$xc|", $class);
-      if (($i + 1) % 16 == 0) debugbr("", $class);
+      debug("$xc|", $debugclass);
+      if (($i + 1) % 16 == 0) debugbr("", $debugclass);
     }
-    debug("</pre><br>", $class);
+    debug("</pre><br>", $debugclass);
   }
 }
 // ..................................................................
@@ -658,16 +664,16 @@ function debug_hex($str, $msg="", $class=DBG_DIAGNOSTIC) {
 * Set debugging class(es)
 * Sets the class or classes (OR'ed together) of debug output
 * which will be accepted/rendered on ouput.
-* @param integer $class    Class of output
+* @param integer $debugclass    Class of output
 */
-function debug_class($class="") {
+function debug_class($debugclass="") {
   global $RESPONSE;
   $currentclass = DBG_UNDEFINED;
   if (isset($RESPONSE)) {
-    if ($class != "") {
-      $RESPONSE->debugger->debug_class($class);
+    if ($debugclass != "") {
+      $RESPONSE->debugger->debug_class($debugclass);
     }
-    $currentclass = $RESPONSE->debugger->class;
+    $currentclass = $RESPONSE->debugger->debugclass;
   }
   // Return current class setting..
   return $currentclass;
@@ -676,12 +682,12 @@ function debug_class($class="") {
 /**
 * Set debugging on
 * Sets the debugging on. Sets class(es) to accept.
-* @param integer $class    Class of output
+* @param integer $debugclass    Class of output
 */
-function debug_on($class=DBG_DEFAULT) {
+function debug_on($debugclass=DBG_DEFAULT) {
   global $RESPONSE;
   if (isset($RESPONSE)) {
-    $RESPONSE->debugger->debug_mode(ON, $class);
+    $RESPONSE->debugger->debug_mode(ON, $debugclass);
   }
 }
 // ..................................................................
