@@ -46,11 +46,22 @@ function unique_filename($prefix="", $extn="") {
   $fname = md5( $prefix . microtime() . $extn );
   $fname = $prefix . $fname;
   if ($extn != "") {
-    $fname .= ".$extn";
+    $fname .= '.$extn';
   }
   return $fname;
 } // unique_filename
 
+// ----------------------------------------------------------------------
+/** Finally got around to implementing this file content reader for
+* backward compatibility. (Kudos to Nigel McNie). This function
+* file_get_contents will return the entire file as a string. 
+*/
+if (!function_exists('file_get_contents')) {
+  function file_get_contents($filename) {
+    return implode('', file($filename));
+  }
+}
+
 // ----------------------------------------------------------------------
 /**
 * Make sure path exists
@@ -194,20 +205,9 @@ class inputfile {
       $this->name = basename($name);
     }
 
-    // Full pathnames..
-    $this->datafname = $this->dir . "/" . $this->name;
-    clearstatcache();
-    if (file_exists($this->datafname) && is_file($this->datafname)) {
-      $this->fp = fopen($this->datafname, "r");
-      if ($this->fp === false) {
-        $this->opened = false;
-      }
-      else {
-        $this->opened = true;
-        $this->filesize = filesize($this->datafname);
-      }
-    }
-    return $this->opened;
+    // Open the file..
+    return $this->openfile($this->dir . "/" . $this->name);
+    
   } // inputfile
   // ....................................................................
   /**
@@ -216,11 +216,13 @@ class inputfile {
   */
   function readall() {
     if ($this->opened) {
-      $this->content = fread($this->fp, $this->filesize);
+      $this->content = file_get_contents($this->datafname);
       return $this->content;
     }
-    else return false;
-  }
+    else {
+      return false;
+    }
+  } // readall
   // ....................................................................
   /**
   * Reads the next line of the file, up to max chars specified.
@@ -233,23 +235,50 @@ class inputfile {
       return rtrim($buf);
     }
     else return false;
-  }
+  } // readln
   // ....................................................................
-  /** Return true if at end-of-file or not opened, else false */
+  /** Return true if at end-of-file or not opened, else false.
+   * @return boolean True if we are at End Of File
+   */
   function eof() {
     $eof = true;
     if ($this->opened) {
       $eof = feof($this->fp);
     }
     return $eof;
-  }
+  } // oef
+  // ....................................................................
+  /** Open a new file, or the default file as defined by the path in the
+   * class variable 'datafname'. If $path is defined then this becomes
+   * the new default file.
+   * @param string $path Path to file, blank means open default file.
+   * @return boolean True if file was opened ok.
+   */
+  function openfile($path="") {
+    if ($path != "") {
+      $this->datafname = $path;
+    }
+    clearstatcache();
+    if (file_exists($this->datafname) && is_file($this->datafname)) {
+      $this->fp = fopen($this->datafname, "r");
+      if ($this->fp === false) {
+        $this->opened = false;
+      }
+      else {
+        $this->opened = true;
+        $this->filesize = filesize($this->datafname);
+      }
+    }
+    return $this->opened;
+  } // openfile
   // ....................................................................
   /** Close the file */
   function closefile() {
     if ($this->opened) {
       fclose($this->fp);
+      $this->opened = false;
     }
-  }
+  } // closefile
 } // inputfile class
 
 // ----------------------------------------------------------------------
@@ -648,6 +677,28 @@ class quickfile extends outputfile {
   } // quickfile
 } // quickfile class
 
+// ----------------------------------------------------------------------
+/**
+* This is a derived class from inputfile and is a quick way of grabbing
+* all content of a file in a single hit. The resulting string is available
+* as the class 'content' variable, and the variable 'readok' indicates
+* whether the read was a success. File is read, then immediately closed.
+* @package file
+*/
+class quickfile_read extends inputfile {
+  /** True if file was read in successfully */
+  var $readok = false;
+  
+  /** @param $path Path to file to read */
+  function quickfile_read($path) {
+    $this->inputfile($path);
+    if ($this->readall() !== false) {
+      $this->readok = true;
+    }
+    $this->closefile();
+  } // quickfile_read
+} // quickfile_read class
+
 // ----------------------------------------------------------------------
 // FILEUPLOAD CLASS
 
@@ -990,5 +1041,118 @@ class fileupload {
   } // storeall
 } // fileupload class
 
+// ----------------------------------------------------------------------
+/**
+ * A generic system configuration file. Extend this for particular types
+ * of config file, such as .INI, shell definitions etc. Automatically
+ * calls the import_settings() method on instantiation.
+ */
+class configfile {
+  /** Path to the config file */
+  var $path;
+  /** Config settings as an associative array (name=value) */
+  var $settings = array();
+  /** True if config is read in & valid */
+  var $valid = false;
+  
+  // ....................................................................
+  function configfile($path) {
+    $this->path = $path;
+    $this->import_settings();
+  } // configfile
+  
+  // ....................................................................
+  /** Return value of  named setting, if it exists.. */ 
+  function getvalue($name) {
+    $val = "";
+    if ($this->valid && $this->settingexists($name)) {
+      $val = $this->settings[$name];
+    }
+    return $val;
+  } // getvalue
+  
+  // ....................................................................
+  /** Return true if named setting is defined */
+  function settingexists($name) {
+    return isset($this->settings[$name]);
+  }
+  
+  // ....................................................................
+  /** Return number of config settings */
+  function settingscount() {
+    return count($this->settings());
+  }
+  
+  // ....................................................................
+  /**
+   * This will be implemented in the child class depending
+   * on config file type.
+   */
+  function import_settings() {
+  }
+  
+} // configfile class
+
+// ----------------------------------------------------------------------
+/**
+ * A system configuration file in the form of a shell script. These are
+ * in the standard NAME=VALUE format, but implemented as 'sh' scripts so
+ * that other scripts can use them via '.'. This class is provided to
+ * allow Php scripts to easily access the config settings in these too.
+ * NOTE: this does not cope with run-time settings in shell format. Eg.
+ * entries of the form: MYVAR=${OTHERVAR}/mydir. Ie. it doesn't expand
+ * the value of ${OTHERVAR} to produce the final setting.  
+ * Use the 'getvalue()' method to access the read-in vars.
+ */
+class shellconfigfile extends configfile {
+  function shellconfigfile($path) {
+    $this->configfile($path);
+  } // shellconfigfile
+  // ....................................................................
+  /** Process the configfile. */
+  function import_settings() {
+    $this->settings = array();
+    $config = new quickfile_read($this->path);
+    if ($config->readok) {
+      $this->valid = true;
+      $pattern = "/([\\w\\S]+=[\"']*.+[\"'\w]*)/";
+      $matched = preg_match_all($pattern, $config->content, $matches);
+      if ($matched > 0 && count($matches[1]) > 0) {
+        foreach ($matches[1] as $match) {
+          $bits  = explode("=", $match);
+          $name  = $bits[0];
+          $value = trim($bits[1], "\"' ");
+          $this->settings[$name] = $value;
+        } // foreach
+      }
+    }
+  } // import_settings
+  
+} // shellconfigfile class
+
+// ----------------------------------------------------------------------
+/**
+ * A system configuration file in the form of an INI file. These are
+ * in the standard NAME=VALUE format, within sections. In this class
+ * we ignore the [sections], and just read in all of the NAME=VALUE
+ * pairs, stashing them into the 'settings' class var as an array.
+ * Use the 'getvalue()' method to access the read-in vars.
+ */
+class iniconfigfile extends configfile {
+  function iniconfigfile($path) {
+    $this->configfile($path);
+  } // iniconfigfile  
+  // ....................................................................
+  /** Process the configfile. */
+  function import_settings() {
+    $this->settings = array();
+    if (file_exists($this->path)) {
+      $this->valid = true;
+      $this->settings = parse_ini_file($this->path);
+    }
+  } // import_settings
+  
+} // shellconfigfile class
+
 // ----------------------------------------------------------------------
 ?>
\ No newline at end of file
