@@ -26,7 +26,7 @@
 var digs=' ,0123456789';
 // IMPOSE INTEGER LIMITS - will rewrite field
 function limitInt(fmelem, lo, hi, dflt) {
-  vali = parseInt(fmelem.value.replace(/\$|,|%/g, ''));
+  var vali = parseInt(fmelem.value.replace(/\$|,|%/g, ''));
   if (isNaN(vali)) {
     if (dflt) vali = dflt;
     else vali = lo;
@@ -37,44 +37,72 @@ function limitInt(fmelem, lo, hi, dflt) {
 }
 // VALIDATE FIELD IS NON-BLANK
 function isNonBlank(fmelem, failmsg) {
+  var i, c;
   var ok=true;
+
   if (fmelem.type == 'select-one') {
-    if (fmelem.selectedIndex == -1) ok=false;
-    else if (fmelem.options[fmelem.selectedIndex].value == '') ok=false;
+    if (fmelem.selectedIndex == -1) {
+      ok=false;
+    }
+    else if (fmelem.options[fmelem.selectedIndex].value == '') {
+      ok=false;
+    }
+  }
+  else {
+    if ((fmelem.value == null) || (fmelem.value == '')) {
+        ok=false;
+    }
+
+    for (i = 0; i < fmelem.value.length; i++) {
+        c = fmelem.value.charAt(i);
+        if (c != '\s') {
+        return ok;
+        }
+    }
+    ok=false;
+  }
+
+  if (!ok) {
+    valFail(fmelem, failmsg);
+  }
+  else {
+    return ok;
   }
-  else if (trimStr(fmelem.value) == '') ok=false;
-  if (!ok) valFail(failmsg);
-  return ok;
 }
 // VALIDATE FIELD IS ONLY DIGITS
 function isOnlyDigits(fmelem, failmsg) {
   var ok=true;
   if (fmelem.value.length > 0) ok=strDigits(fmelem.value);
-  if (!ok) valFail(failmsg);
+  if (!ok) valFail(fmelem, failmsg);
   return ok;
 }
 // VALIDATE FIELD HAS VALID DATE d[d]/m[m]/yyyy or d[d]-m[m]-yyyy
 function isValidDate(fmelem, failmsg) {
   var ok=true;
   if (fmelem.value.length > 0) ok=strValidDate(fmelem.value);
-  if (!ok) valFail(failmsg);
+  if (!ok) valFail(fmelem, failmsg);
   return ok;
 }
 // VALIDATE FIELD HAS VALID TIME [H]H:MM[:SS][ AM|PM]
 function isValidTime(fmelem, failmsg) {
   var ok=true;
   if (fmelem.value.length > 0) ok=strValidTime(fmelem.value);
-  if (!ok) valFail(failmsg);
+  if (!ok) valFail(fmelem, failmsg);
   return ok;
 }
 // UTILITY FUNCTIONS - called by validation functions above
 // String is non-null and all digits
-// Generic validation popup.
-function valFail(msg) {
- if (msg != '') {
-   var s='\n\nNOTE: your data entry has failed validation.\n';
-   alert(s + msg + '\n\n');
- }
+
+// Generic validation popup, field highlighting and keyboard focus.
+function valFail(fmelem, failmsg) {
+  if (failmsg != '') {
+    var s='\n\nNOTE: your data entry has failed validation.\n';
+    alert(s + failmsg + '\n\n');
+  }
+  if (fmelem) {
+    fmelem.style.backgroundColor='rgb(255,255,0)';
+    if(fmelem.type.substr(0,6)!='select') fmelem.select();
+  }
 }
 // String is a numeric/number
 function strNumeric(s) {
