@@ -68,12 +68,12 @@ define("INLINE",            "inline");
 /** MIME content is an attachment
 * @access private */
 define("ATTACH",            "attachment");
-/** Carriage-return Linefeed sequence
+/** End of Line
 * @access private */
-define('CRLF',              "\r\n");
+define('EOL',              "\n");
 /** The body of the e-mail
 * @access private */
-define("BODY",              CRLF . "BODY" . CRLF);
+define("BODY",              EOL . "BODY" . EOL);
 
 // -------------------------------------------------------------------------
 /**
@@ -355,7 +355,7 @@ class email {
       $this->errors[] = "attach_file: could not open '$path' for reading";
       return false;
     }
-    $contenttype .= ";\r\n\tname=" . basename($path);
+    $contenttype .= ";" . EOL . "\tname=" . basename($path);
     $data = fread($fp, filesize($path));
     debug_trace();
     return $this->attach($data,
@@ -442,28 +442,28 @@ class email {
       }
       // Splits data stream into 76 char lines
       // to fit RFC2045 semantics..
-      $emsg = chunk_split($emsg);
+      $emsg = chunk_split($emsg, 76, EOL);
     }
 
-    
+
     //Check if content-type is text/plain and if charset is not specified append default CHARSET
     if (strstr($contenttype, CONTENT_TEXT) && !strstr(contenttype, "/;charset=/i")) {
-      $contenttype .= ";\r\n\tcharset=" . $this->charset;
+      $contenttype .= ";" . EOL . "\tcharset=" . $this->charset;
     }
     $msg = "";
-    $msg .= "Content-Type: $contenttype" . CRLF;
-    $msg .= "Content-Transfer-Encoding: $encoding" . CRLF;
+    $msg .= "Content-Type: $contenttype" . EOL;
+    $msg .= "Content-Transfer-Encoding: $encoding" . EOL;
     if ($disp != "") {
       $msg .= "Content-Disposition: $disp";
       if ($description != "") {
         $msg .= "; filename=\"$description\"";
       }
-      $msg .= CRLF;
+      $msg .= EOL;
     }
     elseif ($description != "" && BODY != $description) {
-      $msg .= "Content-Description: $description" . CRLF;
+      $msg .= "Content-Description: $description" . EOL;
     }
-    $msg .= CRLF . $emsg . CRLF;
+    $msg .= EOL . $emsg . EOL;
     BODY == $description ? $this->mimeparts[0] = $msg : $this->mimeparts[] = $msg;
 
     return count($this->mimeparts);
@@ -484,9 +484,9 @@ class email {
     // Case 1: Attachment list is there.  Therefore MIME Message header must have multipart/mixed
     if (is_array($this->mimeparts) && ($nparts > 1)) {
       $this->build_header("MIME-Version", "1.0");
-      $this->build_header("Content-Type", "$this->mimecontenttype;" . CRLF . "\tboundary=\"$this->mimeboundary\"");
+      $this->build_header("Content-Type", "$this->mimecontenttype;" . EOL . "\tboundary=\"$this->mimeboundary\"");
       $this->build_header("Content-Transfer-Encoding", ENC_BIT7);
-      $msg .= CRLF . MIME_WARNING . CRLF . CRLF ;
+      $msg .= EOL . MIME_WARNING . EOL . EOL;
 
       // Since we are here, it means we do have attachments and
       // the body must become an attachment too..
@@ -496,15 +496,15 @@ class email {
       // Now create the MIME parts of the email
       foreach ($this->mimeparts as $mimepart) {
         if (!empty($mimepart)) {
-          $msg .= CRLF . '--' . $this->mimeboundary . CRLF . $mimepart . CRLF;
+          $msg .= EOL . '--' . $this->mimeboundary . EOL . $mimepart . EOL;
         }
       }
-      $msg .= "--" . $this->mimeboundary . "--" . CRLF;
+      $msg .= "--" . $this->mimeboundary . "--" . EOL;
     }
     else {
-      $this->build_header("Content-Type", "$this->mimecontenttype;" . CRLF . "\tcharset=" . $this->charset);
+      $this->build_header("Content-Type", "$this->mimecontenttype;" . EOL . "\tcharset=" . $this->charset);
       if (!empty($this->body)) {
-        $msg .= CRLF . $this->body . CRLF . CRLF;
+        $msg .= EOL . $this->body . EOL . EOL;
       }
     }
     debug_trace();
@@ -526,6 +526,13 @@ class email {
     }
     if (!empty($this->from)) {
       $this->build_header("From", $this->from);
+      // Make sure any bounces go to the right place..
+      if (!isset($this->email_headers["Return-Path"])) {
+        $this->build_header("Return-Path", $this->from);
+      }
+      if (!isset($this->email_headers["Errors-To"])) {
+        $this->build_header("Errors-To", $this->from);
+      }
     }
     if (!empty($this->replyto)) {
       $this->build_header("ReplyTo", $this->replyto);
@@ -619,7 +626,7 @@ class email {
                 implode(",", $this->to),
                 $this->subject,
                 $this->content,
-                implode(CRLF, $headers),
+                implode(EOL, $headers),
                 "-f$this->from"
                 );
     }
@@ -628,7 +635,7 @@ class email {
                 implode(",", $this->to),
                 $this->subject,
                 $this->content,
-                implode(CRLF, $headers)
+                implode(EOL, $headers)
                 );
     }
     // Debug output..
@@ -708,4 +715,4 @@ function friendlyName($fullname) {
 } // friendlyName
 
 // -------------------------------------------------------------------------
-?>
+?>
\ No newline at end of file
