@@ -624,7 +624,7 @@ class sitemenu extends menu {
       $tryagain = ($this->language != 0);
       $q  = "SELECT *";
       $q .= "  FROM ax_menu m, ax_menuoption mo";
-      $q .= " WHERE m.menu_name='" . addslashes($this->menu_name) . "'";
+      $q .= " WHERE m.menu_name='" . escape_string($this->menu_name) . "'";
       $q .= "   AND m.lang_id=$this->language";
       $q .= "   AND mo.menu_id=m.menu_id";
       if ($this->menu_level != MENU_LEVEL_ALL) {
@@ -927,7 +927,7 @@ class menuop_instance {
     $this->desc = $desc;
     $this->action = $act;
     $this->target = $targ;
-    $this->authcode = $auth;
+    $this->authcode = $authcode;
     $this->parent = $parent;
     $this->is_parent = $is_parent;
   } // menuop_instance
@@ -1158,7 +1158,7 @@ class menu_instance {
       $tryagain = ($this->language != 0);
       $q  = "SELECT *";
       $q .= "  FROM ax_menu m, ax_menuoption mo";
-      $q .= " WHERE m.menu_name='" . addslashes($this->menu_name) . "'";
+      $q .= " WHERE m.menu_name='" . escape_string($this->menu_name) . "'";
       $q .= "   AND m.lang_id=$this->language";
       $q .= "   AND mo.menu_id=m.menu_id";
       $q .= "   AND m.active=TRUE";
