@@ -184,7 +184,7 @@ class menumaintainer extends HTMLObject {
     $qByName .= " WHERE m.lang_id=$this->language";
     $qByName .= "   AND l.lang_id=m.lang_id";
     if ($this->menu_name != "") {
-      $qByName .= " AND menu_name='" . addslashes($this->menu_name) . "'";
+      $qByName .= " AND menu_name='" . escape_string($this->menu_name) . "'";
     }
     $qByID  = "SELECT * FROM ax_menu m, ax_language l";
     $qByID .= " WHERE m.menu_id=$this->menu_id";
@@ -1214,7 +1214,9 @@ class menumaintainer extends HTMLObject {
                   // Set the resulting menu action..
                   if ($menuaction != "") {
                     // Fix leading slash for action and sitepage if reqd..
-                    if (substr($menuaction, 0, 1) != "/" && !protocol_prefixed($menuaction)) {
+                    if (substr($menuaction, 0, 1) != "/"
+                      && substr($menuaction, 0, 11) != "javascript:"
+                      && !protocol_prefixed($menuaction)) {
                       $menuaction = "/$menuaction";
                       if ($sitepage != MENU_ITEM_URL) {
                         $um->set("sitepage", $menuaction);
@@ -1234,7 +1236,7 @@ class menumaintainer extends HTMLObject {
               // Save menu properties..
               global $menu_name, $language, $menu_desc, $menu_user_groups, $menu_active;
               $mu = new dbupdate("ax_menu");
-              $mu->where("menu_id='" . addslashes($this->menu_id) . "'");
+              $mu->where("menu_id='" . escape_string($this->menu_id) . "'");
               $mu->set("menu_name", $menu_name);
               $mu->set("lang_id", $language);
               $mu->set("menu_name", $menu_name);
