@@ -150,7 +150,7 @@ class enc_qualifier extends RenderableObject {
     if ($this->scheme_id != "" && $this->qual_name != "") {
       $q  = "SELECT * FROM ax_enc_qualifier";
       $q .= " WHERE enc_scheme_id=$this->scheme_id";
-      $q .= "   AND qual_name='" . addslashes($this->qual_name) . "'";
+      $q .= "   AND qual_name='" . escape_string($this->qual_name) . "'";
       $qual = dbrecordset($q);
       if ($qual->hasdata) {
         $this->qual_label     = $qual->field("qual_label");
@@ -308,6 +308,7 @@ class metadata_scheme extends RenderableObject {
     $words = explode(" ", $this->description);
     if (count($words) > $maxwords) {
       $pattern = "/(([\S]+[\s]+){1," . $maxwords . "})/";
+      $matches = array();
       preg_match($pattern, $this->description, $matches);
       if (isset($matches[1])) {
         $desc = $matches[1];
@@ -564,7 +565,7 @@ class metadata_element extends RenderableObject {
 
         // Get schema details..
         $q  = "SELECT * FROM ax_meta_schema";
-        $q .= " WHERE schema_name='" . addslashes($this->schema_name) . "'";
+        $q .= " WHERE schema_name='" . escape_string($this->schema_name) . "'";
         $schema = dbrecordset($q);
         if ($schema->hasdata) {
           $this->schema_namespace = $schema->field("namespace");
@@ -591,7 +592,7 @@ class metadata_element extends RenderableObject {
       $q  = "SELECT *";
       $q .= "  FROM ax_site_meta_element";
       $q .= " WHERE element_id=$this->element_id";
-      $q .= "   AND schema_name='" . addslashes($this->schema_name) . "'";
+      $q .= "   AND schema_name='" . escape_string($this->schema_name) . "'";
       $elem = dbrecordset($q);
       if ($elem->hasdata) {
         $this->label = $elem->field("label");
@@ -624,7 +625,7 @@ class metadata_element extends RenderableObject {
       $q  = "SELECT es.preferred_enc_scheme,ese.enc_scheme_id";
       $q .= "  FROM ax_meta_element_set es, ax_element_set_enc ese";
       $q .= " WHERE es.element_id=$this->element_id";
-      $q .= "   AND es.schema_name='" . addslashes($this->schema_name) . "'";
+      $q .= "   AND es.schema_name='" . escape_string($this->schema_name) . "'";
       $q .= "   AND ese.element_id=es.element_id";
       $q .= "   AND ese.schema_name=es.schema_name";
       $schemesQ = dbrecordset($q);
@@ -663,7 +664,7 @@ class metadata_element extends RenderableObject {
       while ($parent_elemid != "") {
         $q  = "SELECT * FROM ax_element_set_enc ese, ax_meta_element e";
         $q .= " WHERE ese.element_id=$parent_elemid";
-        $q .= "   AND ese.schema_name='" . addslashes($this->schema_name) . "'";
+        $q .= "   AND ese.schema_name='" . escape_string($this->schema_name) . "'";
         $q .= "   AND e.element_id=ese.element_id";
         $parentschemes = dbrecordset($q);
         if ($parentschemes->hasdata) {
@@ -798,6 +799,7 @@ class metadata_element extends RenderableObject {
     $words = explode(" ", $this->description);
     if (count($words) > $maxwords) {
       $pattern = "/(([\S]+[\s]+){1," . $maxwords . "})/";
+      $matches = array();
       preg_match($pattern, $this->description, $matches);
       if (isset($matches[1])) {
         $desc = $matches[1];
@@ -1277,7 +1279,7 @@ class layout_metadata_elements {
         $meup = new dbupdate("ax_layout_metadata");
         $meup->where("layout_id=$this->layout_id");
         $meup->where("AND element_id=$element->element_id");
-        $meup->where("AND schema_name='" . addslashes($element->schema_name) . "'");
+        $meup->where("AND schema_name='" . escape_string($element->schema_name) . "'");
       }
       else {
         $meup = new dbinsert("ax_layout_metadata");
@@ -1315,7 +1317,7 @@ class layout_metadata_elements {
       $medel = new dbdelete("ax_layout_metadata");
       $medel->where("layout_id=$this->layout_id");
       $medel->where("AND element_id=$element->element_id");
-      $medel->where("AND schema_name='" . addslashes($element->schema_name) . "'");
+      $medel->where("AND schema_name='" . escape_string($element->schema_name) . "'");
       $medel->execute();
     }
   } // remove_metadata_element
