@@ -92,7 +92,7 @@ class DB_dbfunction extends dbfunction {
   // ....................................................................
   function DB_dbfunction(&$schema, $name, $returns="", $src="", $args="", $lang="plpgsql",
                       $volatile="v", $strict=false) {
-    $this->dbfunction($scheme, $name, $returns, $src, $args, $lang);
+    $this->dbfunction($schema, $name, $returns, $src, $args, $lang);
     $this->volatile = $volatile;
     $this->strict = $strict;
   }
@@ -429,8 +429,8 @@ class DB_dbfield extends dbfield {
   // ....................................................................
   function DB_dbfield(&$schema, $name, $num, $type, $defaultval="", $notnull=false, $ispkey=false, $isarray=false) {
     // Strip out any postgres typecast..
-    $bits = explode("::", $defaultval);
-    $defaultval = $bits[0];    
+    //$bits = explode("::", $defaultval);
+    //$defaultval = $bits[0];    
     $this->dbfield($schema, $name, $num, $type, $defaultval, $notnull, $ispkey);
     $this->isarray = $isarray;
   }
@@ -639,6 +639,7 @@ class DB_dbtable extends dbtable {
               $conname = $checks->field("rcname");
               $consrc = $checks->field("rcsrc");
               $conbin = $checks->field("rcbin");
+              $matches = array();
               if (preg_match("/.*?varattno ([0-9]+).*?/", $conbin, $matches)) {
                 $attnum = $matches[1];
                 $con = new dbconstraint($this->schema, $conname, "c");
