@@ -401,7 +401,7 @@ class plugin extends page_section {
       $this->plugin_contents[] = new object_plugin_content($content);
     }
     elseif (is_string($content)) {
-      $pattern = "/^.+\(.*\)" . chr(36) . "/";
+      $pattern = "/^[\S]+\(.*\)" . chr(36) . "/";
       if (preg_match($pattern, $content)) {
         // A function definition..
         $this->plugin_contents[] = new func_plugin_content($content);
@@ -526,6 +526,7 @@ class func_plugin_content extends plugin_content {
   */
   function func_plugin_content($funcdef) {
     $pattern = "/^(.+)\((.*)\)" . chr(36) . "/";
+    $matches = array();
     if (preg_match($pattern, $funcdef, $matches)) {
       $this->funcname = $matches[1];
       $argstr = $matches[2];
