@@ -430,6 +430,7 @@ class response extends webpage {
         // OPERA
         if (eregi("opera", $HTTP_USER_AGENT)) {
           $this->browser = BROWSER_OPERA;
+          $matches = array();
           if (preg_match("/.* opera (.+) .*/i", $HTTP_USER_AGENT, $matches)) {
             if (is_numeric((float) $matches[1])) {
               $this->browser_version = $matches[1];
@@ -442,6 +443,7 @@ class response extends webpage {
         elseif (eregi("msie", $HTTP_USER_AGENT)) {
           $this->browser = BROWSER_IE;
           // IE has its own version number..
+          $matches = array();
           if (preg_match("/.* msie (.+); .*/i", $HTTP_USER_AGENT, $matches)) {
             if (is_numeric((float) $matches[1])) {
               $this->browser_version = $matches[1];
@@ -777,7 +779,7 @@ class response extends webpage {
       if ($this->auth_type == HTTP_AUTHENTICATION) {
         debugbr("HTTP Authentication", DBG_DEBUG);
         if (!isset($PHP_AUTH_USER)) {
-          debugbr("sending HTTP authentication headers", DBG_DEBUG);
+          debugbr("sending HTTP authentication headers", DBG_AUTH);
           header("WWW-Authenticate: Basic realm=\"" . APP_NAME . "\"");
           header("HTTP/1.0 401 Unauthorized");
           return;
@@ -785,12 +787,12 @@ class response extends webpage {
         else {
           // Get the HTTP authentication variables..
           if ($this->get_session_cookie()) {
-            debugbr("already have a valid session..", DBG_DEBUG);
+            debugbr("we already have a valid session", DBG_AUTH);
             if ($this->identify_user()
               && $this->userid == "guest"
               && strtolower($PHP_AUTH_USER != "guest")
             ) {
-              debugbr("overriding guest session with supplied HTTP Auth login..", DBG_DEBUG);
+              debugbr("overriding guest session with supplied HTTP Auth login", DBG_AUTH);
               $tbxUsername = $PHP_AUTH_USER;
               if (isset($PHP_AUTH_PW)) $tbxPassword = $PHP_AUTH_PW;
               else $tbxPassword = "";
@@ -798,7 +800,7 @@ class response extends webpage {
           }
           else {
             // Transform it into our own kind of login sequence..
-            debugbr("morphing to Axyl login..", DBG_DEBUG);
+            debugbr("morphing to Axyl login", DBG_AUTH);
             $tbxUsername = $PHP_AUTH_USER;
             if (isset($PHP_AUTH_PW)) $tbxPassword = $PHP_AUTH_PW;
             else $tbxPassword = "";
@@ -806,7 +808,7 @@ class response extends webpage {
         }
       } // HTTP Auth
       else {
-        debugbr("FORM Authentication.", DBG_DEBUG);
+        debugbr("FORM Authentication", DBG_DEBUG);
       }
     }
 
@@ -831,9 +833,8 @@ class response extends webpage {
       // someone is hacking on our website..
       if (!$this->identify_user()) {
         // Deal with authentication/session create failure..
-        debugbr("response-defs: user not identified.", DBG_DEBUG);
         if (!$this->isvalid()) {
-          debugbr("response-defs: user invalid.", DBG_DEBUG);
+          debugbr("response-defs: user is invalid", DBG_AUTH);
           // Make sure the cookie is removed..
           $this->delete_cookie();
           if ($this->keep_enabled) {
@@ -850,7 +851,7 @@ class response extends webpage {
               break;
 
             case AUTHFAIL_REDIRECT:
-              log_sys("AUTHFAIL_REDIRECT: user=$tbxUsername dest=$this->auth_fail_redirect");
+              log_sys("authfail_redirect: user=$tbxUsername dest=$this->auth_fail_redirect");
               header("Location: $this->auth_fail_redirect");
               exit;
               break;
@@ -860,13 +861,13 @@ class response extends webpage {
               if (isset($tbxUsername) && strtolower($tbxUsername) == "guest") {
                 // Failed guest login should not happen if the guest user
                 // exists and its 'enabled' flag is true..
-                $this->crash(401, "AUTHFAIL_GUEST: Guest logins are not permitted.");
+                $this->crash(401, "authfail_guest: Guest logins are not permitted.");
               }
               else {
                 // Unset everything they might be logging in with, so that
                 // the system will default them into guest mode..
                 if (isset($tbxUsername)) {
-                  debugbr("AUTHFAIL_GUEST: tbxUsername is set '$tbxUsername', setting it to guest.", DBG_DEBUG);
+                  debugbr("authfail_guest: tbxUsername is set [$tbxUsername], setting it to guest.", DBG_AUTH);
                   $tbxUsername = "guest";
                   $tbxPassword = "";
                 }
@@ -879,7 +880,7 @@ class response extends webpage {
         // Otherwise we failed authentication, but the user was
         // valid - a very strange state of affairs..!
         else {
-          debugbr("user '$this->userid' valid but failed authentication", DBG_DEBUG);
+          debugbr("user [$this->userid] valid but failed authentication", DBG_AUTH);
           if ($this->authfail_option != AUTHFAIL_SILENT) {
             $this->crash(500, "No session!");
           }
@@ -898,8 +899,13 @@ class response extends webpage {
     if ($logged_in) {
       if ($this->login_type == LOGIN_BY_PASSWD) {
         if ($this->password_expired() && $this->requested != "/axyl-login.php") {
-          header("Location: /axyl-login.php");
-          exit;
+          if ($this->browser_type == BROWSER_TYPE_WML || $this->browser_type == BROWSER_TYPE_WMLUP) {
+            header("Location: /axyl-login.php?authid=".$this->get_auth_code());
+            exit;
+          } else {
+            header("Location: /axyl-login.php");
+            exit;
+          }
         }
       }
     }
@@ -1246,7 +1252,7 @@ class response extends webpage {
     $this->auth_fail_option = $option;
     $this->auth_fail_redirect = $redirect;
   } // on_authentication_fail
-  
+
   // ...................................................................
   /**
    * Set the hostname of the machine serving this Axyl website. This is
@@ -1259,7 +1265,7 @@ class response extends webpage {
       $this->site_url  = "http://$this->http_host";
     }
   } // set_http_host
-  
+
   // ...................................................................
   /**
   * Add database
@@ -1391,8 +1397,8 @@ class response extends webpage {
   function check_group_membership() {
     // Find page and group permissions if we can..
     $q  = "SELECT * FROM ax_sitepage p, ax_sitepage_group sg, ax_group g";
-    $q .= " WHERE p.page_path='" . addslashes($this->requested) . "'";
-    $q .= "   AND p.page_title='" . addslashes($this->head->title) . "'";
+    $q .= " WHERE p.page_path='" . escape_string($this->requested) . "'";
+    $q .= "   AND p.page_title='" . escape_string($this->head->title) . "'";
     $q .= "   AND sg.page_id=p.page_id";
     $q .= "   AND g.group_id=sg.group_id";
     $allowed = dbrecordset($q);
@@ -1538,6 +1544,19 @@ if (file_exists("$DOCUMENT_ROOT/application.xml") && isset($application) && $app
   // Activate the response, determine user etc..
   $RESPONSE->activate();
 
+  // SEARCH ENGINE
+  // Determine the basics - do we have one available?
+  if (isset($CONTEXT) && ($CONTEXT->configvalue("Search Engine Host") != "")) {
+    $SE_AVAILABLE = true;
+    $SE_HOST = $CONTEXT->configvalue("Search Engine Host");
+    $SE_PORT = $CONTEXT->configvalue("Search Engine Port");
+    debugbr("search engine available: host [$SE_HOST] port [$SE_PORT]", DBG_DEBUG);
+  }
+  else {
+    $SE_AVAILABLE = false;
+    debugbr("search engine not available", DBG_DEBUG);
+  }
+
   // SET MICROSITE THEME
   if ($RESPONSE->microsites_mode == MICROSITES_ENABLED) {
     debugbr("microsite features are enabled", DBG_DEBUG);
@@ -1571,7 +1590,7 @@ if (file_exists("$DOCUMENT_ROOT/application.xml") && isset($application) && $app
           case "/":
           case "/index.php":
             $q  = "SELECT * FROM ax_microsite_page mp, ax_sitepage p";
-            $q .= " WHERE mp.microsite_name='" . addslashes($RESPONSE->microsite_detected) . "'";
+            $q .= " WHERE mp.microsite_name='" . escape_string($RESPONSE->microsite_detected) . "'";
             $q .= "   AND mp.microsite_homepage=TRUE";
             $q .= "   AND p.page_id=mp.page_id";
             $home = dbrecordset($q);
