@@ -148,7 +148,7 @@ class treemenu extends RenderableObject {
     }
     // Check if we can use a menu stored in the session..
     // Manage selected menuoption..
-    if (is_object($webpage)) {
+    if (is_object($webpage) && $webpage->cachecontrol != "refresh") {
       $this->session_id = $webpage->session_id;
       if ($webpage->session_record["menu_status"] != "") {
         debugbr("unserializing menu..");
@@ -165,8 +165,7 @@ class treemenu extends RenderableObject {
       }
     }
     // Create it if it doesn't exist, re-create if required..
-    if (!isset($this->menu)
-    || (isset($cachecontrol) && $cachecontrol == "refresh")) {
+    if (!isset($this->menu)) {
       $this->menu = new menu_instance($this->menu_name, $this->language);
       debugbr("treemenu: new menu generated", DBG_DEBUG);
     }
@@ -332,6 +331,7 @@ class treemenu extends RenderableObject {
       $menu_level = $mop->menu_level;
       $label      = $mop->label;
       $action     = $mop->action;
+      $target     = $mop->target;
       $expanded   = $mop->expanded;
       $heading    = $mop->is_submenuheading(); // Whether it is a heading for sub-menu
       $pseudo     = $mop->is_pseudo();        // Whether it is a pseudo menu-item
@@ -385,14 +385,17 @@ class treemenu extends RenderableObject {
             $widget->setwidth($this->padsize);
           }
         }
-        $widget->sethspace(2);
+        //$widget->sethspace(2);
 
-        // Add selected menu option id to url..
-        $action = href_addparm($action, "_mid", $mopid);
+        // Add selected menu option id to URL, but only if it is
+        // not an off-site URL of some kind..
+        if (!protocol_prefixed($action)) {
+          $action = href_addparm($action, "_mid", $mopid);
 
-        // Make sure our menu gets refreshed and not stuck in a static
-        // state in the web-browser's cache..
-        $action = href_addparm($action, "cachecontrol", "dynamic");
+          // Make sure our menu gets refreshed and not stuck in a static
+          // state in the web-browser's cache..
+          $action = href_addparm($action, "cachecontrol", "dynamic");
+        }
 
         // Padding for this menu level..
         $padding = $this->padimage;
@@ -403,7 +406,7 @@ class treemenu extends RenderableObject {
         $requestedurl = basename($RESPONSE->requested) . ($RESPONSE->requested_query != "" ? "\?$RESPONSE->requested_query" : "");
 
         $pad = new img("$LIBDIR/img/_pad.gif", "", "", $this->label_padding_left, 1);
-        if (!$heading && preg_match("/$requestedurl/i", $action)) {
+        if (!$heading && preg_match(";$requestedurl;i", $action)) {
           $menuop = $padding->render() . $widget->render() . $pad->render() . $label;
           $style = "color:$hicolour;background-color:$hibg;";
         }
@@ -411,6 +414,14 @@ class treemenu extends RenderableObject {
         else {
           $widget_link = new anchor($action, $widget->render());
           $menuop_link = new anchor($action, $label);
+          if (preg_match(";$requestedurl;i", $action) && $mop->is_submenuheading() && trim($mop->action) != "") {
+            $style = "color:$hicolour;background-color:$hibg;";
+            $menuop_link->setcss($style);
+          }
+          if ($target != "") {
+            $widget_link->settarget($target);
+            $menuop_link->settarget($target);
+          }
           $menuop = "";
           if ( $padding->width > 0 ) {
             $menuop .= $padding->render();
