@@ -626,6 +626,7 @@ $RESPONSE->datasource->add_database(
   $password,             // Password for this user
   $targhost,             // Host machine name
   $targport,             // Port number
+  "","ISO",              // Char encoding and datestyle
   DEFAULT_DATASOURCE     // DEFAULT_DATASOURCE, or omit for other databases
   );
 
@@ -635,7 +636,8 @@ $RESPONSE->datasource->add_database(
   $user,                 // Name of user with access to the database
   $password,             // Password for this user
   $refhost,              // Host machine name
-  $refport               // Port number
+  $refport,              // Port number
+  "","ISO"               // Char encoding and datestyle
   );
 
 // Check db's connected ok..
