@@ -400,7 +400,7 @@ class sqlquery {
     }
     // Everything else is a quoted, escaped string..
     else {
-      $this->fields->add($field, "'" . addslashes(trim($val)) . "'");
+      $this->fields->add($field, "'" . escape_string(trim($val)) . "'");
     }
   }
   // ....................................................................
@@ -792,7 +792,7 @@ class dbrecords extends dbrows {
   *    record. We then use the value to lookup in table 'tablename'.
   *    The keyfield is 'keyfield', and the value to return is to
   *    be found in field 'dispfield'. This is foreign key lookup.
-  *  > Finally, if the value is a string, then stripslashes is
+  *  > Finally, if the value is a string, then unescape_string is
   *    done automatically for you.
   *
   * @param string $fieldname The name of the field to return value of
@@ -803,7 +803,7 @@ class dbrecords extends dbrows {
     if ($this->rid) {
       $value = $this->rawfield($fieldname);
       if (is_string($value)) {
-        $value = stripslashes($value);
+        $value = unescape_string($value);
       }
       return $value;
     }
