@@ -224,7 +224,7 @@ $verf = new inputfile($VER_FILE);
 if ($verf->opened) {
   $verf->readall();
   $verf->closefile();
-  $AXYL_VERSION = trim($verf->content);  
+  $AXYL_VERSION = trim($verf->content);
 }
 
 if ($AXYL_VERSION != "") {
@@ -612,7 +612,7 @@ if ($controltable->hasdata) {
     }
     if (!$upcontrol->execute()) {
       logit(" -- ax_control update FAILED!");
-    }    
+    }
   }
   else {
     logit(" -- dropping invalid ax_control table");
@@ -656,7 +656,7 @@ if (!$chkuser->hasdata) {
     dbcommand("ALTER TABLE ax_user ALTER COLUMN passwd_forever SET DEFAULT false");
     dbcommand("UPDATE ax_user SET passwd_forever=false");
     dbcommand("ALTER TABLE ax_user ALTER COLUMN passwd_forever SET NOT NULL");
-  }  
+  }
   create_new_field("ax_user", "passwd_expiry", "timestamp with time zone");
   create_new_field("ax_user", "passwd_history", "text");
   $res = create_new_field("ax_user", "passwd_failures", "int4");
@@ -1551,6 +1551,19 @@ if ($bkt->hasdata) {
             "'/$IMAGESDIR/' . basename('\\2') . '.gif'",
             $content
             );
+
+    $new_content = preg_replace(
+            "/($IMAGESDIR\/)(.+?)(\.jpg)/ie",
+            "'/$IMAGESDIR/' . basename('\\2') . '.jpg'",
+            $new_content
+            );
+
+    $new_content = preg_replace(
+            "/($IMAGESDIR\/)(.+?)(\.png)/ie",
+            "'/$IMAGESDIR/' . basename('\\2') . '.png'",
+            $new_content
+            );
+
     $new_content = preg_replace(
             "/($LIBDIR\/_)(.+?)(\.gif)/ie",
             "'/$LIBDIR/img/_' . basename('\\2') . '.gif'",
@@ -1723,6 +1736,10 @@ if ($VHSERVERNAMES != "") {
             logit(" -- apache configuration reload..");
             exec("invoke-rc.d apache reload");
           }
+          if (file_exists("/usr/sbin/apache-perl")) {
+            logit(" -- apache-perl configuration reload..");
+            exec("invoke-rc.d apache-perl reload");
+          }
           if (file_exists("/usr/sbin/apache-ssl")) {
             logit(" -- apache-ssl configuration reload..");
             exec("invoke-rc.d apache-ssl reload");
@@ -1815,4 +1832,7 @@ $THISDIR = realpath(".");
 if ($THISDIR != "" && $THISDIR != "/") {
   exec("$AXYL_HOME/install/set-axyl-website-perms.sh");
 }
-?>
\ No newline at end of file
+?>
+
+
+
