@@ -15,16 +15,9 @@
 include_once("application.php");
 
 // -------------------------------------------------------------------------
-// CHECK FOR LUCENE
-$lucene_enabled = false;
-$config = new configuration("sys_control");
-if ($config->field_exists("Lucene Site Indexing")) {
-  $lucene_enabled = $config->value("Lucene Site Indexing");
-}
-
 // Flag indicating whether a search has been done..
 $search_is_active =
-   ($lucene_enabled
+   ($SE_AVAILABLE
     && isset($_search_find_x)
     && isset($_search_text)
     && $_search_text != ""
@@ -37,10 +30,10 @@ $search_is_active =
 // a search. Customise as you like. We are currently just plugging this
 // content into the <!--SITE_SEARCH--> position in the template.
 function search_form() {
-  global $lucene_enabled;
+  global $SE_AVAILABLE;
   global $LIBDIR;
   $s = "";
-  if ($lucene_enabled) {
+  if ($SE_AVAILABLE) {
     include_once("form-defs.php");
     $search_textbox = new form_textfield("_search_text");
     $search_textbox->setclass("axsearchbox");
@@ -67,12 +60,13 @@ function search_form() {
 // $_search_ind    Checkbox - Industry and Product Info (site webpages)
 function search_results() {
   global $RESPONSE;
-  global $lucene_enabled, $search_is_active;
+  global $search_is_active;
   global $_search_find_x, $_search_text, $_search_category;
 
   $results = "";
   if ($search_is_active) {
-    include_once("lucene-defs.php");
+    include_once("search-lucene-defs.php");
+    include_once("search-query-defs.php");
 
     // To show story window..
     $RESPONSE->body->add_popup_script(
@@ -80,7 +74,7 @@ function search_results() {
       "toolbar=no,status=yes,scrollbars=yes,resizable=yes"
       );
 
-    // Consult Lucene. We assume that site content is indexed with a common
+    // Consult Search Engine. We assume that site content is indexed with a common
     // field called 'category' which categorises the content. We predefine
     // one such category as "sitecontent" and this means anything within the
     // standard Axyl content-managed blocks. Feel free to define other such
@@ -88,7 +82,7 @@ function search_results() {
     // Tip: if you do this, then you can also add some user controls for them
     // to select which categories to search, eg. with checkboxes next to the
     // search form textbox.
-    $M = new lucene_search();
+    $M = new searchengine_search();
 
     // Always search Axyl managed content..
     $terms[] = "(category:sitecontent AND $_search_text)";
